Learn R Programming

seacarb (version 2.0.2)

carb: Parameters of the seawater carbonate system

Description

Returns parameters of the seawater carbonate system.

Usage

carb(flag, var1, var2, S=35, T=25, P=0, Pt=0, Sit=0)

Arguments

flag
select the couple of variables available. The flags which can be used are:

flag = 1 pH and CO2 given

flag = 2 CO2 and HCO3 given

flag = 3 CO2 and CO3 given

flag = 4 CO2 and ALK given

flag = 5 CO2 and DIC given

flag = 6

var1
enter value of the first variable in mol/kg, except for pH and for pCO2 in $\mu$atm
var2
enter value of the second variable in mol/kg, except for pH
S
Salinity
T
Temperature in degrees Celsius
P
Hydrostatic pressure in bar (surface = 0)
Pt
enter value of the concentration of total phosphate in mol/kg
Sit
enter the value of the total silicate in mol/kg

Value

  • The function returns a data frame containing the following columns:
  • SSalinity
  • TTemperature in degrees Celsius
  • PPressure in bar
  • pHpH
  • CO2CO2 concentration (mol/kg)
  • pCO2pCO2, CO2 partial pressure ($\mu$atm)
  • fCO2fCO2, CO2 fugacity ($\mu$atm)
  • HCO3HCO3 concentration (mol/kg)
  • CO3CO3 concentration (mol/kg)
  • DICDIC concentration (mol/kg)
  • ALKALK, total alkalinity (mol/kg)
  • OmegaAragoniteOmega aragonite, aragonite saturation state
  • OmegaCalciteOmega calcite, calcite saturation state

encoding

latin1

Details

Vectors can be given in enter arguments. If the length of vectors entered are different the longer vector is kept and only the first value of other vectors is used. For instance, to compute parameters from one couple of variable for a range of temperatures, a vector with temperatures required can be given in enter and other arguments can be completed be one variable this variable will be used for each temperatures.

References

Dickson A. G., Sabine C. L. and Christian J. R., 2007 Guide to best practices for ocean CO2 measurements. PICES Special Publication 3, 1-191.

Zeebe, R. E. and Wolf-Gladrow, D. A., 2001 CO2 in seawater: equilibrium, kinetics, isotopes. Amsterdam: Elsevier, 346 pp.

Examples

Run this code
## With a couple of variables
carb(flag=8, var1=8.2, var2=0.00234, S=35, T=25, P=0, Pt=0, Sit=0)

## Using vectors as arguments
flag <- c(8, 2, 8)
var1 <- c(8.2, 7.477544e-06, 8.2)
var2 <- c(0.002343955, 0.001649802, 2400e-6)
S <- c(35, 35, 30)
T <- c(25, 25, 30)
P <- c(0, 0, 0)
Pt <- c(0, 0, 0)
Sit <- c(0, 0, 0)
carb(flag=flag, var1=var1, var2=var2, S=S, T=T, P=P, Pt=Pt, Sit=Sit)

## Test with all flags 
flag <- c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 21, 22, 23, 24, 25)
var1 <- c(8.200000, 7.477544e-06, 7.477544e-06, 7.477544e-06, 7.477544e-06, 8.2, 
8.2, 8.2, 8.2, 0.001685024, 0.001685024, 0.001685024,  0.0002888382, 0.0002888382, 
0.002391252, 264.2008, 264.2008, 264.2008, 264.2008, 264.2008)
var2 <- c(7.477544e-06, 0.001685024, 0.0002888382, 0.002391252, 0.001981340, 
0.001685024, 0.0002888382, 0.002391252, 0.001981340, 0.0002888382, 0.002391252, 
0.001981340,  0.002391252, 0.001981340, 0.001981340, 8.2, 0.001685024, 0.0002888382, 
0.002391252, 0.001981340)
carb(flag=flag, var1=var1, var2=var2)

## Test using a data frame 
data(seacarb_test)
tab <- seacarb_test

## method 1 using the column numbers
carb(flag=tab[[1]], var1=tab[[2]], var2=tab[[3]], S=tab[[4]], T=tab[[5]], P=tab[[6]], 
Sit=tab[[7]], Pt=tab[[8]])

## method 2 using the column names
carb(flag=tab$flag, var1=tab$var1, var2=tab$var2, S=tab$S, T=tab$T, P=tab$P, Sit=tab$Sit, 
Pt=tab$Pt)

Run the code above in your browser using DataLab